# SnowieCaster
This library is created for Snowie project to use Ariadne library.

It currently only supports in-memory backend, but it isn't release version

## Requirements
Python 3.6+
## Installation
* `pip install snowiecaster`
#
